@@ -35,7 +35,7 @@ project_submodel <- function(solution_terms, p_ref, refmodel, regul = 1e-4,
 
 # Function to project the reference model onto the submodels of given model
 # sizes `nterms`. Returns a list of submodels (each processed by
-# .init_submodel()).
+# .init_submodel(), so of class `initsubmodl`).
 .get_submodels <- function(search_path, nterms, p_ref, refmodel, regul,
                            refit_prj = FALSE, ...) {
   if (!refit_prj) {
@@ -88,9 +88,12 @@ project_submodel <- function(solution_terms, p_ref, refmodel, regul = 1e-4,
 
 .init_submodel <- function(submodl, p_ref, refmodel, solution_terms, wobs,
                            wsample) {
-  p_ref$mu <- refmodel$family$linkinv(
-    refmodel$family$linkfun(p_ref$mu) + refmodel$offset
-  )
+  # Take offsets into account (the `if ()` condition is added for efficiency):
+  if (!all(refmodel$offset == 0)) {
+    p_ref$mu <- refmodel$family$linkinv(
+      refmodel$family$linkfun(p_ref$mu) + refmodel$offset
+    )
+  }
   if (!(all(is.na(p_ref$var)) ||
         refmodel$family$family %in% c("gaussian", "Student_t"))) {
     stop("For family `", refmodel$family$family, "()`, .init_submodel() might ",
@@ -100,19 +103,21 @@ project_submodel <- function(solution_terms, p_ref, refmodel, regul = 1e-4,
   }
   if (refmodel$family$family == "Student_t") {
     stop("For the `Student_t()` family, .init_submodel() is not finished yet.")
-    ### TODO (`Student_t()` family): Check if this is needed (perhaps with some
+    ### TODO (Student_t()): Check if this is needed (perhaps with some
     ### modifications) or if something completely different is needed (there
     ### used to be no special handling of the `Student_t()` family here at all):
     # pobs <- pseudo_data(
     #   f = 0, y = p_ref$mu, family = refmodel$family, weights = wobs,
     #   offset = refmodel$offset
     # )
-    # ### TODO: Add `dis` and perhaps other elements here?:
+    # ### TODO (Student_t()): Add `dis` and perhaps other elements here?:
     # p_ref <- list(mu = pobs$z, var = p_ref$var)
     # ###
-    # p_ref$mu <- refmodel$family$linkinv(
-    #   refmodel$family$linkfun(p_ref$mu) + refmodel$offset
-    # )
+    # if (!all(refmodel$offset == 0)) {
+    #   p_ref$mu <- refmodel$family$linkinv(
+    #     refmodel$family$linkfun(p_ref$mu) + refmodel$offset
+    #   )
+    # }
     # wobs <- pobs$wobs
     ###
   }
@@ -125,5 +130,8 @@ project_submodel <- function(solution_terms, p_ref, refmodel, regul = 1e-4,
                        nlist(mu, dis)),
     wsample
   )
-  return(nlist(dis, kl, weights = wsample, solution_terms, submodl))
+  return(structure(
+    nlist(dis, kl, weights = wsample, solution_terms, submodl),
+    class = "initsubmodl"
+  ))
 }
