@@ -10,9 +10,10 @@
 #' @param object An object of class `refmodel` (returned by [get_refmodel()] or
 #'   [init_refmodel()]) or an object that can be passed to argument `object` of
 #'   [get_refmodel()].
-#' @param d_test For internal use only. A `list` providing information about the
-#'   test set which is used for evaluating the predictive performance of the
-#'   reference model. If not provided, the training set is used.
+#' @param d_test A `list` of the structure outlined in section "Argument
+#'   `d_test`" below, providing test data for evaluating the predictive
+#'   performance of the submodels as well as of the reference model. If `NULL`,
+#'   the training data is used.
 #' @param method The method for the search part. Possible options are `"L1"` for
 #'   L1 search and `"forward"` for forward search. If `NULL`, then internally,
 #'   `"L1"` is used, except if the reference model has multilevel or additive
@@ -73,16 +74,28 @@
 #' @param verbose A single logical value indicating whether to print out
 #'   additional information during the computations.
 #' @param seed Pseudorandom number generation (PRNG) seed by which the same
-#'   results can be obtained again if needed. If `NULL`, no seed is set and
-#'   therefore, the results are not reproducible. See [set.seed()] for details.
-#'   Here, this seed is used for clustering the reference model's posterior
-#'   draws (if `!is.null(nclusters)`) and for drawing new group-level effects
-#'   when predicting from a multilevel submodel (however, not yet in case of a
-#'   GAMM).
+#'   results can be obtained again if needed. Passed to argument `seed` of
+#'   [set.seed()], but can also be `NA` to not call [set.seed()] at all. Here,
+#'   this seed is used for clustering the reference model's posterior draws (if
+#'   `!is.null(nclusters)`) and for drawing new group-level effects when
+#'   predicting from a multilevel submodel (however, not yet in case of a GAMM).
 #' @param ... Arguments passed to [get_refmodel()] as well as to the divergence
 #'   minimizer (during a forward search and also during the evaluation part, but
 #'   the latter only if `refit_prj` is `TRUE`).
 #'
+#' @details
+#'
+#' # Argument `d_test`
+#'
+#' If not `NULL`, then `d_test` needs to be a `list` with the following
+#' elements:
+#' * `data`: a `data.frame` containing the predictor variables for the test set.
+#' * `offset`: a numeric vector containing the offset values for the test set
+#' (if there is no offset, use a vector of zeros).
+#' * `weights`: a numeric vector containing the observation weights for the test
+#' set (if there are no observation weights, use a vector of ones).
+#' * `y`: a numeric vector containing the response values for the test set.
+#'
 #' @details Arguments `ndraws`, `nclusters`, `nclusters_pred`, and `ndraws_pred`
 #'   are automatically truncated at the number of posterior draws in the
 #'   reference model (which is `1` for `datafit`s). Using less draws or clusters
@@ -186,7 +199,7 @@ varsel.refmodel <- function(object, d_test = NULL, method = NULL,
     rng_state_old <- get(".Random.seed", envir = .GlobalEnv)
     on.exit(assign(".Random.seed", rng_state_old, envir = .GlobalEnv))
   }
-  set.seed(seed)
+  if (!is.na(seed)) set.seed(seed)
 
   refmodel <- object
 
@@ -202,14 +215,11 @@ varsel.refmodel <- function(object, d_test = NULL, method = NULL,
   search_terms <- args$search_terms
 
   if (is.null(d_test)) {
-    d_type <- "train"
-    test_points <- seq_len(NROW(refmodel$y))
-    d_test <- nlist(
-      y = refmodel$y, test_points, data = NULL, weights = refmodel$wobs,
-      type = d_type, offset = refmodel$offset
-    )
+    d_test <- list(type = "train", data = NULL, offset = refmodel$offset,
+                   weights = refmodel$wobs, y = refmodel$y)
   } else {
-    d_type <- d_test$type
+    d_test$type <- "test"
+    d_test <- d_test[nms_d_test()]
   }
 
   ## reference distributions for selection and prediction after selection
@@ -231,10 +241,13 @@ varsel.refmodel <- function(object, d_test = NULL, method = NULL,
     p_ref = p_pred, refmodel = refmodel, regul = regul, refit_prj = refit_prj,
     ...
   )
-  sub <- .get_sub_summaries(
-    submodels = submodels, test_points = seq_along(refmodel$y),
-    refmodel = refmodel
-  )
+  sub <- .get_sub_summaries(submodels = submodels,
+                            refmodel = refmodel,
+                            test_points = NULL,
+                            newdata = d_test$data,
+                            offset = d_test$offset,
+                            wobs = d_test$weights,
+                            y = d_test$y)
 
   ## predictive statistics of the reference model on test data. if no test data
   ## are provided,
@@ -242,16 +255,29 @@ varsel.refmodel <- function(object, d_test = NULL, method = NULL,
   if (inherits(refmodel, "datafit")) {
     ## no actual reference model, so we don't know how to predict test
     ## observations
-    ntest <- NROW(refmodel$y)
-    ref <- list(mu = rep(NA, ntest), lppd = rep(NA, ntest))
+    nobs_test <- nrow(d_test$data %||% refmodel$fetch_data())
+    ref <- list(mu = rep(NA, nobs_test), lppd = rep(NA, nobs_test))
   } else {
-    if (d_type == "train") {
-      mu_test <- refmodel$family$linkinv(
-        refmodel$family$linkfun(refmodel$mu) + refmodel$offset
-      )
+    if (d_test$type == "train") {
+      mu_test <- refmodel$mu
+      if (!all(refmodel$offset == 0)) {
+        mu_test <- refmodel$family$linkinv(
+          refmodel$family$linkfun(mu_test) + refmodel$offset
+        )
+      }
     } else {
+      newdata_for_ref <- d_test$data
+      if (inherits(refmodel$fit, "stanreg") &&
+          length(refmodel$fit$offset) > 0) {
+        if ("projpred_internal_offs_stanreg" %in% names(newdata_for_ref)) {
+          stop("Need to write to column `projpred_internal_offs_stanreg` of ",
+               "`d_test$data`, but that column already exists. Please rename ",
+               "this column in `d_test$data` and try again.")
+        }
+        newdata_for_ref$projpred_internal_offs_stanreg <- d_test$offset
+      }
       mu_test <- refmodel$family$linkinv(
-        refmodel$ref_predfun(refmodel$fit, newdata = d_test$data) +
+        refmodel$ref_predfun(refmodel$fit, newdata = newdata_for_ref) +
           d_test$offset
       )
     }
@@ -268,7 +294,7 @@ varsel.refmodel <- function(object, d_test = NULL, method = NULL,
     d_test,
     summaries = nlist(sub, ref),
     solution_terms = search_path$solution_terms,
-    kl = sapply(submodels, function(x) x$kl),
+    kl = sapply(submodels, "[[", "kl"),
     nterms_max,
     nterms_all = count_terms_in_formula(refmodel$formula),
     method = method,
@@ -366,7 +392,10 @@ parse_args_varsel <- function(refmodel, method, refit_prj, nterms_max,
     nclusters <- 1
   }
 
-  max_nv_possible <- count_terms_chosen(search_terms, duplicates = TRUE)
+  search_terms_unq <- unique(unlist(
+    strsplit(search_terms, split = "+", fixed = TRUE)
+  ))
+  max_nv_possible <- count_terms_chosen(search_terms_unq, duplicates = TRUE)
   if (is.null(nterms_max)) {
     nterms_max <- 19
   }
